@@ -7,13 +7,14 @@
  * Author: Russell Stuart, russell-conspy@stuart.id.au
  *         22/05/2003
  *
- * To compile:	cc conspy.c -O2 -o conspy -lncurses
+ * To compile:
+ *   gcc -Werror -Wall -Wextra -O2 --std=c99 -lncurses -o conspy conspy.c
  *
  *
  * License
  * -------
  *
- * Copyright (c) 2005,2006,2007,2008,2009 Russell Stuart.
+ * Copyright (c) 2005,2006,2007,2008,2009,2011 Russell Stuart.
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -50,8 +51,8 @@ extern int errno;
 /*
  * Version info.
  */
-static char conspy_date[]	= "2009-08-23";
-static char conspy_version[]	= "1.7";
+static char conspy_date[]	= "2011-04-17";
+static char conspy_version[]	= "1.8";
 
 /*
  * VGA colour definitions, as found in a nibble in an attribute
@@ -237,6 +238,7 @@ static struct option options[] =
   {
     {"version",		0,	0,	'V'},
     {"viewonly",	0,	0,	'v'},
+    {0,0,0,0},
   };
 
 /*
@@ -298,7 +300,7 @@ static void process_command_line(int argc, char** argv)
 {
   char*			end;
   int			opt;
-  int			optindex;
+  size_t		optindex;
   char			opts[(sizeof(options) / sizeof(*options))*2 + 1];
   char 			vcc_name[sizeof(device_name)];
   int			vcc_errno;
@@ -536,7 +538,7 @@ static void conspy(int use_colour)
   unsigned short	box;
   int			buffer_size;
   int			bytes_read;
-  int			column;
+  unsigned int		column;
   attr_t		curses_attribute;
   short			curses_colour;
   int			escape_pressed;
@@ -549,7 +551,7 @@ static void conspy(int use_colour)
   unsigned int		last_attribute;
   unsigned int		last_columns;
   unsigned int		last_rows;
-  int			line;
+  unsigned int		line;
   chtype		line_buf[256];
   int			line_chars;
   fd_set		readset;
@@ -582,7 +584,7 @@ static void conspy(int use_colour)
       syserror(device_name);
     buffer_size = 4 +
 	vidbuf.vidbuf_lines * vidbuf.vidbuf_columns * sizeof(struct vidchar);
-    if (buffer_size > sizeof(vidbuf))
+    if (buffer_size > (int)sizeof(vidbuf))
     {
       fprintf(
 	  stderr, "%s: screen too large.  I only handle up to 200x80.\n", me);
@@ -594,14 +596,14 @@ static void conspy(int use_colour)
     /*
      * If the screen size has changed blank out the unused portions.
      */
-    if (vidbuf.vidbuf_lines < last_rows && last_rows < LINES)
+    if (vidbuf.vidbuf_lines < last_rows && last_rows < (unsigned)LINES)
     {
       move(vidbuf.vidbuf_lines, 0);
       clrtobot();
     }
-    if (vidbuf.vidbuf_columns < last_columns && last_columns < COLS)
+    if (vidbuf.vidbuf_columns < last_columns && last_columns < (unsigned)COLS)
     {
-      for (line = 0; line < last_rows && line < LINES; line += 1)
+      for (line = 0; line < last_rows && line < (unsigned)LINES; line += 1)
       {
 	move(line, last_columns);
 	clrtoeol();
@@ -613,12 +615,12 @@ static void conspy(int use_colour)
      * Write the data to the screen.
      */
     vidchar = vidbuf.vidbuf_chars;
-    for (line = 0; line < vidbuf.vidbuf_lines && line < LINES; line += 1)
+    for (line = 0; line < vidbuf.vidbuf_lines && line < (unsigned)LINES; line += 1)
     {
       line_chars = 0;
       for (column = 0; column < vidbuf.vidbuf_columns; column += 1)
       {
-	if (column >= COLS)
+	if (column >= (unsigned)COLS)
 	{
 	  vidchar += vidbuf.vidbuf_columns - column;
 	  break;
