@@ -37,14 +37,16 @@ debian/rules clean
 # Build the www directory.
 #
 rm -rf ${PACKAGE}
-mkdir -p ${PACKAGE}/rpm/{BUILD,RPMS,SOURCES,SPECS,SRPMS}
-(cd ..; tar cfz "${ME}/${PACKAGE}/${ME}.tar.gz" --exclude="${ME}/debian" --exclude="${ME}/${PACKAGE}" Specfile "${ME}")
-cp ChangeLog AUTHORS README epl-v10.html "${PACKAGE}.html" "${PACKAGE}"
+mkdir -p "${PACKAGE}"
+(cd ..; tar cfz "${ME}/${PACKAGE}/${ME}.tar.gz" --exclude="${ME}/debian" --exclude="${ME}/${PACKAGE}" --exclude="${ME}/.pc" "${ME}")
+cp -a ChangeLog AUTHORS README epl-v10.html "${PACKAGE}.html" "${PACKAGE}"
+ln -s "${PACKAGE}.html" conspy/index.html
 man2html <"${PACKAGE}.1" | sed >"${PACKAGE}/conspy.1.html" -e 1,2d -e 7,8d -e '/^<HR>/,/^Time: /d'
-echo >"${PACKAGE}/rpm/rpmrc" "macrofiles : /usr/lib/rpm/macros:/usr/lib/rpm/i686-linux/macros:/etc/rpm/macros.specspo:/etc/rpm/macros.db1:/etc/rpm/macros.cdb:/etc/rpm/macros:/etc/rpm/i686-linux/macros:${PWD}/${PACKAGE}/rpm/rpmmacros"
-echo >"${PACKAGE}/rpm/rpmmacros" "%_topdir ${PWD}/${PACKAGE}/rpm"
-TAR_OPTIONS=--wildcards rpmbuild -ta --rcfile "/usr/lib/rpm/rpmrc:${PACKAGE}/rpm/rpmrc" "${PACKAGE}/${ME}.tar.gz"
-mv ${PACKAGE}/rpm/SRPMS/${ME}-1ras.src.rpm ${PACKAGE}
-mv "${PACKAGE}/rpm/RPMS/x86_64/${ME}-1ras.x86_64.rpm" "${PACKAGE}"
-rm -r "${PACKAGE}/rpm"
+#mkdir -p ${PACKAGE}/rpm/{BUILD,RPMS,SOURCES,SPECS,SRPMS}
+#echo >"${PACKAGE}/rpm/rpmrc" "macrofiles : /usr/lib/rpm/macros:/usr/lib/rpm/i686-linux/macros:/etc/rpm/macros.specspo:/etc/rpm/macros.db1:/etc/rpm/macros.cdb:/etc/rpm/macros:/etc/rpm/i686-linux/macros:${PWD}/${PACKAGE}/rpm/rpmmacros"
+#echo >"${PACKAGE}/rpm/rpmmacros" "%_topdir ${PWD}/${PACKAGE}/rpm"
+#TAR_OPTIONS=--wildcards rpmbuild -ta --rcfile "/usr/lib/rpm/rpmrc:${PACKAGE}/rpm/rpmrc" "${PACKAGE}/${ME}.tar.gz"
+#mv ${PACKAGE}/rpm/SRPMS/${ME}-1ras.src.rpm ${PACKAGE}
+#mv "${PACKAGE}/rpm/RPMS/x86_64/${ME}-1ras.x86_64.rpm" "${PACKAGE}"
+#rm -r "${PACKAGE}/rpm"
 cp "${PACKAGE}/${ME}.tar.gz" "../${ME%-*}_${VERSION}.orig.tar.gz"
